@@ -62,6 +62,11 @@ may default.
                the xs files to scan for MODULE lines.
                the default is 'xs/*.xs'.
 
+  xs_files     use this to supply an explicit list of file
+               names (as an array reference) to use instead
+               of a glob pattern.  the default is to use
+               the glob pattern.
+
   ignore       regular expression matching any and all 
                module names which should be ignored, i.e.
                NOT included in the list of symbols to boot.
@@ -133,18 +138,20 @@ sub write_boot {
 		'glob' => 'xs/*.xs',
 		@_,
 	);
-	my $filename = $opts{filename};
-	my $glob = $opts{'glob'};
 	my $ignore = $opts{ignore};
 
-	my $file = IO::File->new (">$filename")
-		or carp "Cannot write $filename: $!"; 
+	my $file = IO::File->new (">$opts{filename}")
+		or carp "Cannot write $opts{filename}: $!"; 
 
 	print $file "\n\n/* This file is automatically generated, any changes made here will be lost! */\n\n";
 
 	my %boot=();
 
-	foreach my $xsfile (glob $glob) {
+	my @xs_files = 'ARRAY' eq ref $opts{xs_files}
+	             ? @{ $opts{xs_files} }
+	             : glob $opts{'glob'};
+
+	foreach my $xsfile (@xs_files) {
 		my $in = IO::File->new ($xsfile)
 				or die "can't open $xsfile: $!\n";
 
