@@ -16,7 +16,7 @@
 # along with this library; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
 #
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.39 2003/10/10 03:36:35 muppetman Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gtk2/Gtk2.pm,v 1.44 2003/11/14 04:43:18 muppetman Exp $
 #
 
 package Gtk2;
@@ -31,14 +31,18 @@ use Glib;
 
 require DynaLoader;
 
-our $VERSION = '1.00';
+our $VERSION = '1.011';
 
 our @ISA = qw(DynaLoader);
 
 sub import {
-	my $self = shift;
+	my $class = shift;
 	foreach (@_) {
-		$self->init,	next if /^-init$/;
+		if (/^-?init$/) {
+			$class->init;
+		} else {
+			$class->VERSION ($_);
+		}
 	}
 }
 
@@ -217,6 +221,9 @@ easier to use.
 L<Gtk2::Pango>(3pm) exports various little-used but important constants you
 may need to work with pango directly.
 
+L<Gtk2::index>(3pm) lists the autogenerated api documentation pod files
+for Gtk2.
+
 Gtk2 also provides code to make it relatively painless to create perl
 wrappers for other GLib/Gtk-based libraries.  See L<Gtk2::CodeGen>,
 L<Glib::PkgConfig>, and L<ExtUtils::Depends>.  If you're writing bindings,
